@@ -29,6 +29,15 @@ def define_mnist_model(input_shape, hidden_neurons, num_classes=10):
     return model
 
 
+class MNIST_small(MNIST):
+    """docstring for MNIST_small."""
+    def __init__(self, *args, **kwargs):
+        super(MNIST_small, self).__init__(*args, **kwargs)
+
+    def __len__(self):
+        return 100
+
+
 class LightningMNISTClassifier(pl.core.LightningModule):
 
     def __init__(self):
@@ -94,22 +103,29 @@ class LightningMNISTClassifier(pl.core.LightningModule):
 
         # prepare transforms standard to MNIST
         tempdir = tempfile.mkdtemp()
-        mnist_train = MNIST(tempdir, train=True, download=True,
+        mnist_train = MNIST_small(tempdir, train=True, download=True,
                             transform=transform)
-        mnist_test = MNIST(tempdir, train=False, download=True,  # noqa: F841, E501
+        mnist_test = MNIST_small(tempdir, train=False, download=True,  # noqa: F841, E501
                            transform=transform)
 
         self.mnist_train, self.mnist_val = random_split(mnist_train,
-                                                        [55000, 5000])
+                                                        [80, 20])
+
+        # def train_len(self):
+        #     return 100
+
+        # self.mnist_train.__len__ = 100
+        # self.mnist_val.__len__ = 100
+
 
     def train_dataloader(self):
-        return DataLoader(self.mnist_train, batch_size=64)
+        return DataLoader(self.mnist_train, batch_size=10)
 
     def val_dataloader(self):
-        return DataLoader(self.mnist_val, batch_size=64)
+        return DataLoader(self.mnist_val, batch_size=10)
 
     def test_dataloader(self):
-        return DataLoader(self.mnist_test, batch_size=64)
+        return DataLoader(self.mnist_test, batch_size=10)
 
     def configure_optimizers(self):
         optimizer = torch.optim.Adam(self.parameters(), lr=1e-3)
@@ -125,10 +141,43 @@ class TestTracking(unittest.TestCase):
         # set_project('a0583ec5-bdf3-4526-a985-05be15e62f16')
 
     def test_log_param(self):
-        from segmind import log_param  # noqa: F401
+        from segmind import log_param
+        log_param(
+            key='test_param',
+            value='A')
+
+    def test_log_params(self):
+        from segmind import log_params
+        log_params(
+            params={
+                'test_params1': 100,
+                'test_params2': 56
+            })
 
     def test_log_metric(self):
-        from segmind import log_metric  # noqa: F401
+        from segmind import log_metric
+
+        log_metric(key='test_step_metric', value=100, step=1)
+        log_metric(key='test_step_metric', value=200, step=5)
+        log_metric(key='test_step_metric', value=300, step=10)
+
+        log_metric(key='test_epoch_metric', value=100, epoch=1)
+        log_metric(key='test_epoch_metric', value=150, epoch=2)
+        log_metric(key='test_epoch_metric', value=200, epoch=3)
+
+    def test_log_metrics(self):
+        from segmind import log_metrics
+
+        log_metrics(metrics={
+                'test_batch_metric1': 50,
+                'test_batch_metric2': 1
+            },
+            step=10)
+        log_metrics(metrics={
+                'test_batch_metric1': 100,
+                'test_batch_metric2': 50
+            },
+            step=20)
 
     def test_log_batch(self):
         from segmind import log_batch
@@ -163,7 +212,7 @@ class TestKerasCallback(unittest.TestCase):
         # set_project('a0583ec5-bdf3-4526-a985-05be15e62f16')
 
     def test_callback(self):
-        from segmind import KerasCallback
+        from segmind.keras import KerasCallback
 
         fashion_mnist = keras.datasets.fashion_mnist
         (train_images,
@@ -192,12 +241,12 @@ class TestLightningCallback(unittest.TestCase):
         # set_project('a0583ec5-bdf3-4526-a985-05be15e62f16')
 
     def test_callback(self):
-        from segmind import LightningCallback
+        from segmind.pytorch_lightning import LightningCallback
 
         model = LightningMNISTClassifier()
 
         lightning_cb = LightningCallback()
-        trainer = pl.Trainer(callbacks=[lightning_cb], max_epochs=2)
+        trainer = pl.Trainer(callbacks=[lightning_cb], max_epochs=1)
 
         trainer.fit(model)
 
@@ -212,14 +261,14 @@ class TestXGBoostCallback(unittest.TestCase):
         from sklearn.datasets import load_breast_cancer
         from sklearn.model_selection import train_test_split
 
-        from segmind import XGBoost_callback
+        from segmind.xgboost import XGBoost_callback
 
         X, y = load_breast_cancer(return_X_y=True)
         X_train, X_valid, y_train, y_valid = train_test_split(X, y, random_state=0)
         D_train = xgb.DMatrix(X_train, y_train)
         D_valid = xgb.DMatrix(X_valid, y_valid)
 
-        num_boost_round = 100
+        num_boost_round = 10
 
         # Pass it to the `callbacks` parameter as a list.
         xgb.train(
@@ -231,7 +280,7 @@ class TestXGBoostCallback(unittest.TestCase):
             D_train,
             evals=[(D_train, 'Train'), (D_valid, 'Valid')],
             num_boost_round=num_boost_round,
-            callbacks=[XGBoost_callback(period=25)])
+            callbacks=[XGBoost_callback(period=5)])
 
 
 if __name__ == '__main__':
